#!/bin/bash
#
# mount-manager:bin/api/crypt-api.sh
#
declare -r KEY_ID='mount-manager'
#declare -r KEY_ID=$(id --name --user)

# Internal
function encrypt_gpg {
  local password="$1"

  echo -n "${password}" | gpg --armor --encrypt --batch --recipient "${KEY_ID}"
  local gpg_rc=$?

  if [ ! ${gpg_rc} -eq 0 ]; then
    echo "** pgp error: ${gpg_rc}" >&2
    exit 1
  fi
}

#
# API: decrypt <password_to_encrypt>
#
function encrypt {
  local password_to_encrypt="$1"
  local encrypt_gpg_value=

  encrypt_gpg "${password_to_encrypt}" | while IFS='' read -r line || [[ -n "${line}" ]]; do
    echo -n "${line}^"
  done

  echo
}

# Internal
function decrypt_gpg {
  local encrypt_gpg_value="$1"

  echo -n "${encrypt_gpg_value}" | gpg --decrypt --batch 2>/dev/null
  local gpg_rc=$?

  if [ ! ${gpg_rc} -eq 0 ]; then
    echo "** pgp error: ${gpg_rc}" >&2
    exit 1
  fi
}

#
# API: decrypt <encrypted_string>
#
function decrypt {
  local encrypted="$1"
  local encrypt_gpg_value=

  encrypt_gpg_value="$(
    echo "${encrypted}" | cut -d'^' --output-delimiter='
' -f1-
    )"

  decrypt_gpg "${encrypt_gpg_value}"
}
