#!/bin/bash
#
# mount-manager:bin/api/diskimage-api.sh
#

#
# mount *.img, *.dd or *.iso files
#
function mount_diskimage {
  local -r disk_image_file="$1"
  local -r mountdir="$2"

  if [ ! -f "${disk_image_file}" ]; then
    echo "Cannot find image : '${disk_image_file}'" >&2
    exit 1
  fi

  create_mountdir_if_needed "${mountdir}"

  echo_verbose "mount -v -o loop,ro '${disk_image_file}' '${mountdir}'"

  sudo mount -v -o loop,ro "${disk_image_file}" "${mountdir}"
}

#
# API: mount_diskimage_by_mountdir mountdir
#
# mountdir : Full path of mount folder
#
function mount_diskimage_by_mountdir {
  local -r mountdir="$1"
  local diskimage_file=
  local diskimage_mountdir=

  for id in $( get_all_diskimage_ids ); do
    diskimage_mountdir="$( get_diskimage_mountdir "${id}" )"

    if [ "${mountdir}" = "${diskimage_mountdir}" ]; then
      diskimage_file="$( get_diskimage_imagefile "${id}" )"
      break
    fi
  done

  if [ -z "${diskimage_file}" ]; then
    echo "*** No disk image for '${mountdir}'" >&2
    exit 1
  fi

  if [ ! -f "${diskimage_file}" ]; then
    echo "*** Cannot find or access to '${diskimage_file}' for '${mountdir}'" >&2
  else
    mount_diskimage "${diskimage_file}" "${mountdir}"
  fi
}

#
# API: mount_all_diskimage
#
function mount_all_diskimage {
  local id=
  local image=
  local mount_name=
  local mountdir=

  for mountdir in $( get_all_diskimage_mountdir ); do

    mount_name="$( echo "${mountdir}" | rev | cut -d'/' -f1 |rev )"
    id="$( get_diskimage_id_from_mountname "${mount_name}" )"

    if [ -z "${id}" ]; then
      echo "** Error cannot find disk_image for '${mountdir}'" >&2
    else

      image="$( get_diskimage_imagefile "${id}" )"
      mount_diskimage "${image}" "${mountdir}"
    fi

  done
}

#
# API: umount_all_diskimage
#
function umount_all_diskimage {
  local mountdir=

  for mountdir in $( get_all_diskimage_mountdir ); do
    umount_by_mountdir "${mountdir}"
  done
}

#
# API: build_checkboxes_for_diskimage
#
function build_checkboxes_for_diskimage {
  local disk_image_file=
  local mountdir=
  local mounted_status=

  for diskimage_id in $( get_all_diskimage_ids ); do
    mountdir="$( get_diskimage_mountdir "${diskimage_id}" )"
    disk_image_file="$( get_diskimage_imagefile "${diskimage_id}" )"

    mounted_status="$( get_mounted_status "${mountdir}" )"
    update_context_according_to_mount_status "${mounted_status}"

    CHECKBOXES+=("${mountdir}" "${disk_image_file}" "${mounted_status}")
  done
}

