#!/bin/bash
#
# mount-manager:bin/api/nfs-api.sh (ALPHA-VERSION)
#

#
# API: get_all_nfs_ids
#
function get_all_nfs_ids {
  get_type_ids 'nfs'
}

#
# API: get_nfs_shares NFS_ID
#
function get_nfs_shares {
  local -r nfs_id="$1"

  get_type_value 'nfs' "${nfs_id}" 'shares[]'
}

#
# API: get_nfs_mountdir NFS_ID SERVER_SHARE
#
function get_nfs_mountdir {
  local -r nfs_id="$1"
  local -r server_share="$2"

  get_mountdir "${nfs_id}/${server_share}"
}

#
# API: get_all_nfs_mountdir
#
function get_all_nfs_mountdir {
  local nfs_id=
  local share=

  for nfs_id in $( get_all_nfs_ids ); do
    while read -r share; do
      # print mount_dir
      get_nfs_mountdir "${nfs_id}" "${share}"
    done < <( get_nfs_shares "${nfs_id}" )
  done
}

# Internal
function __mount_nfs__ {
  local -r username="$1"
  local -r password="$2"
  local -r server_ip="$3"
  local -r server_share="$4"
  local -r server_prefix="$5"
  local    mountdir=

  mountdir="$( get_nfs_mountdir "${server_prefix}" "${server_share}" )"

  local -r share="${server_ip}:/${server_share}"

  create_mountdir_if_needed "${mountdir}"

  #sudo mount 1.2.3.4:/var/nfs /mnt/nfs/var/nfs
  cat <<EOF >&2
  sudo mount -vvv -t nfs4 -o "user=${username},password=${password}" "${share}" "${mountdir}"
EOF
  sudo mount -vvv -t nfs4 -o "user=${username},password=${password}" "${share}" "${mountdir}"
}

#
# API: mount_all_nfs
#
function mount_all_nfs {
  local ip=
  local nfs_id=
  local password=
  local share=
  local shares=
  local username=

  for nfs_id in $( get_all_nfs_ids ); do
    ip="$( get_type_value 'nfs' "${nfs_id}" 'ip' )"
    password="$( get_password_by_type_id 'nfs' "${nfs_id}" 'password' )" || exit 1
    shares="$( get_nfs_shares "${nfs_id}" )"
    username="$( get_type_value 'nfs' "${nfs_id}" 'username' )"

    for share in ${shares}; do
      __mount_nfs__ "${username}" "${password}" "${ip}" "${share}" "${nfs_id}"
    done
  done
}

#
# API: umount_all_nfs
#
function umount_all_nfs {
  local mountdir=

  while read -r mountdir ; do
    umount_by_mountdir "${mountdir}"
  done < <( get_all_nfs_mountdir )
}

# Internal
function __build_nfs_sharepath__ {
  local -r server_ip="$1"
  local -r server_share="$2"

  echo "${server_ip}:${server_share}"
}

#
# API: build_checkboxes_for_nfs
#
function build_checkboxes_for_nfs {
  local id=
  local ip=
  local mountdir=
  local mounted_status=
  local share_name=
  local share_path=

  for id in $( get_all_nfs_ids ); do
    ip="$( get_type_value 'nfs' "${id}" 'ip' )" || exit 1

    while read -r share_name; do

      mountdir="$( get_nfs_mountdir "${id}" "${share_name}" )"
      share_path="$( __build_nfs_sharepath__ "${ip}" "${share_name}" )"

      mounted_status="$( get_mounted_status "${mountdir}" )"
      update_context_according_to_mount_status "${mounted_status}"

      CHECKBOXES+=("${mountdir}" "${share_path}" "${mounted_status}")
    done < <( get_nfs_shares "${id}" )
  done
}
